<?php

/**
 * Charger les fonctions d'outillage pour la page d'administration des plugins
 *
 * @package SPIP\SVP\Fonctions
 **/
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

include_spip('inc/svp_outiller');
